function w = tukeywinf(L,r)
%HAMMINGF Reimplementation of tukeywin function from Signal Processing
%Toolbox
%   w = tukeywin(L,r) returns an L-point Tukey window in the column vector,
%   w. A Tukey window is a rectangular window with the first and last r/2
%   percent of the samples equal to parts of a cosine. See Algorithms for
%   the equation that defines the Tukey window. r is a real number between
%   0 and 1. If you input r ? 0, you obtain a rectwin window. If you input
%   r ? 1, you obtain a hann window. r defaults to 0.5.

if ~exist('r','var')
    r = 0.5;
end

ind = linspace(0,1,L);

if (r<=0)
    w = ones(L,1);
    return;
elseif (r>=1)
    w = hannf(L);
    return;
end

w(0 <= ind & ind < (r/2)) = 0.5*(1 + cos(((2*pi)/r)*(ind - (r/2))));
w((r/2) < ind & ind < 1-(r/2)) = 1;
w(1-(r/2) <= ind & ind <= 1) = 0.5*(1 + cos(((2*pi)/r)*(ind - 1 + (r/2))));

